@@ -22,6 +22,14 @@
 
 
 
+/*
+ * Local defines
+ */
+#define   SNOOPY_DATASOURCE_DATETIME_defaultFormat      "%FT%T%z"
+#define   SNOOPY_DATASOURCE_DATETIME_sizeMaxWithNull    80
+
+
+
 /*
  * SNOOPY DATA SOURCE: datetime
  */
